==> de-BBBike-3.13.tbz: BBBike/Bundle/BBBike.pm <==
# -*- perl -*-

package Bundle::BBBike;

$VERSION = sprintf("%d.%02d", q$Revision: 2.2 $ =~ /(\d+)\.(\d+)/);

1;

__END__

=head1 NAME

Bundle::BBBike - A bundle to install all dependencies of BBBike

=head1 SYNOPSIS

 perl -MCPAN -e 'install Bundle::BBBike'

=head1 CONTENTS

Tk 402.002	- das absolute Muss!

Tk::FireButton	- "Firebutton"-Funktionalitt fr die Windrose

Tk::Pod 2.8	- Online-Hilfe

Tk::FontDialog	- zum ndern des Zeichensatzes aus dem Programm heraus

Tk::JPEG

Tie::Watch

Tk::HistEntry

Tk::Stderr	- optionales Redirect von Fehlermeldungen in ein Tk-Fenster

LWP::UserAgent	- fr die WWW-Verbindungen (Stadtplan und Wetterbericht)

Image::Magick	- fr Bildmanipulationen beim Radar-Bild der FU

Apache::Session::DB_File	- optionale Session-Verwaltung fr das CGI-Programm

XML::SAX	- CPAN.pm kann XML::SAX nicht ber XML::Simple automatisch installieren

XML::Simple	- optional fr XML-Dumps der BBBike-Route

YAML	- optional fr YAML-Dumps der BBBike-Route

Mail::Send	- falls man aus bbbike heraus E-Mails mit der Routenbeschreibung verschicken will

String::Approx 2.7	- oder man verwendet agrep (mindestens Version 3.0)

Storable	- fr das Caching beim CGI-Programm

MLDBM

GD 1.18	- zum On-the-fly-Erzeugen von Grafiken beim CGI-Programm

Chart::ThreeD::Pie	- Tortendiagramme in der Statistik

List::Permutor	- Fr das Problem des Handlungsreisenden

PDF::Create 0.06	- Erzeugung der Route als PDF-Dokument --- die neueste Version ist nur auf sourceforge erhltlich! (http://prdownloads.sourceforge.net/perl-pdf/perl-pdf-0.06.1b.tar.gz?download)

BSD::Resource

Devel::Peek

Statistics::Descriptive

Math::MatrixReal

Class::Accessor	- fr GPS::GpsmanData, die ESRI-Module etc.

Template	- fr BBBikeDraw::MapServer

Inline::C	- fr den schnelleren Suchalgorithmus, siehe ext/Strassen-Inline

Pod::Usage	- fr das Ausgeben der 'Usage' in einigen Entwicklungs-Tools

Palm::PalmDoc	- fr das Erzeugen von palmdoc-Dateien mit der Routenbeschreibung

Astro::Sunrise	- Anzeige des Sonnenuntergangs/-aufgangs im Info-Fenster

File::ReadBackwards	- LogTracker plugin

Date::Calc	- LogTracker plugin

XBase	- Erzeugen der Mapserver- oder anderer ESRI-Dateien

IPC::Run	- hilft bei der sicheren Ausfhrung von externen Kommandos (insbesondere fr Win32)

Imager	- additional optional BBBikeDraw backend for PNG graphics

SVG	- additional optional BBBikeDraw backend for SVG graphics

Image::Info

Test::More



=head1 DESCRIPTION

Dieses BE<uuml>ndel listet alle erforderlichen und empfohlenen Module
fE<uuml>r BBBike auf. Bis auf B<Tk> sind alle anderen Module optional.

This bundle lists all required and optional perl modules for BBBike.
Only B<Tk> is really required, all other modules are optional.

=head1 AUTHOR

Slaven Rezic <slaven@rezic.de>

=cut

==> de-BBBike-3.15.tbz: BBBike/Bundle/BBBike.pm <==
# -*- perl -*-

package Bundle::BBBike;

$VERSION = sprintf("%d.%02d", q$Revision: 1.1 $ =~ /(\d+)\.(\d+)/);

1;

__END__

=head1 NAME

Bundle::BBBike - A bundle to install all dependencies of BBBike

=head1 SYNOPSIS

 perl -I`pwd` -MCPAN -e 'install Bundle::BBBike'

=head1 CONTENTS


Tk 800.000	- das absolute Muss!

Tk::FireButton	- "Firebutton"-Funktionalitt fr die Windrose

Tk::Pod 2.8	- Online-Hilfe

Tk::FontDialog	- zum ndern des Zeichensatzes aus dem Programm heraus

Tk::JPEG

Tie::Watch

Tk::HistEntry

Tk::Stderr	- optionales Redirect von Fehlermeldungen in ein Tk-Fenster

Tk::DateEntry 1.38

LWP::UserAgent	- fr die WWW-Verbindungen (z.B. Wetterbericht)

Image::Magick	- fr Bildmanipulationen beim Radar-Bild der FU

Apache::Session::DB_File	- optionale Session-Verwaltung fr das CGI-Programm, notwendig fr wapbbbike

Apache::Session::Counted	- optionale aber sehr zu empfehlende Session-Verwaltung fr das CGI-Programm

XML::SAX	- CPAN.pm kann XML::SAX nicht ber XML::Simple automatisch installieren

XML::Simple	- optional fr XML-Dumps der BBBike-Route

XML::Parser	- optional fr UAProf parsing (alternative wre XML::SAX::PurePerl)

XML::LibXML	- optional fr das Parsen von GPX-Dateien

YAML	- optional fr YAML-Dumps der BBBike-Route sowie fuer temp_blockings

Mail::Send	- falls man aus bbbike heraus E-Mails mit der Routenbeschreibung verschicken will

String::Approx 2.7	- oder man verwendet agrep (mindestens Version 3.0)

String::Similarity	- optional fr den temp_blockings-Editor

Storable	- fr das Caching beim CGI-Programm

MLDBM

GD 1.18	- zum On-the-fly-Erzeugen von Grafiken beim CGI-Programm

Chart::ThreeD::Pie	- Tortendiagramme in der Statistik

List::Permutor	- Fr das Problem des Handlungsreisenden

PDF::Create 0.06	- Erzeugung der Route als PDF-Dokument --- die neueste Version ist nur auf sourceforge erhltlich! (http://prdownloads.sourceforge.net/perl-pdf/perl-pdf-0.06.1b.tar.gz?download)

Font::Metrics::Helvetica	- Fr die Reparatur der Zeichenbreitentabellen in PDF::Create

BSD::Resource

Devel::Peek

Statistics::Descriptive

Math::MatrixReal

Class::Accessor	- fr GPS::GpsmanData, die ESRI-Module etc.

Template	- fr BBBikeDraw::MapServer

Inline::C	- fr den schnelleren Suchalgorithmus, siehe ext/Strassen-Inline

Pod::Usage	- fr das Ausgeben der 'Usage' in einigen Entwicklungs-Tools

Palm::PalmDoc	- fr das Erzeugen von palmdoc-Dateien mit der Routenbeschreibung

Astro::Sunrise	- Anzeige des Sonnenuntergangs/-aufgangs im Info-Fenster

File::ReadBackwards	- LogTracker plugin, Edititeren

Date::Pcalc	- LogTracker plugin (Alternative wre Date::Calc)

XBase	- Erzeugen der Mapserver- oder anderer ESRI-Dateien, notwendig fr radzeit.de

IPC::Run	- hilft bei der sicheren Ausfhrung von externen Kommandos (insbesondere fr Win32)

Imager	- additional optional BBBikeDraw backend for PNG graphics

Image::ExifTool	- fr geocode_images

SVG	- additional optional BBBikeDraw backend for SVG graphics

Object::Iterate	- Notwendig fr die radzeit.de-Version (bbd2esri)

Image::Info

Test::More

Test::Differences

Test::NoWarnings

WWW::Mechanize	- Fr Testen des CGI-Interfaces


=head1 DESCRIPTION

Dieses BE<uuml>ndel listet alle erforderlichen und empfohlenen Module
fE<uuml>r BBBike auf. Bis auf B<Tk> sind alle anderen Module optional.

This bundle lists all required and optional perl modules for BBBike.
Only B<Tk> is really required, all other modules are optional.

=head1 AUTHOR

Slaven Rezic <slaven@rezic.de>

=cut
